/**
 * Settings Javascript actions
 *
 * @category   Ajax
 * @package    Settings
 * @author     Jonathan Hernandez <ion@gluch.org.mx>
 * @author     Pablo Fischer <pablo@pablo.com.mx>
 * @author     Ali Fazelzadeh <afz@php.net>
 * @copyright   2004-2024 Jaws Development Group
 * @license    http://www.gnu.org/copyleft/lesser.html
 */
function Jaws_Gadget_Settings() { return {
    // ASync callback method
    AjaxCallback : {
    },

    /**
     * Update advanced settings
     */
    submitAdvancedForm: function() {
        this.gadget.ajax.call(
            'UpdateAdvancedSettings',
            $.unserialize($('#settingsForm input,select,textarea').serialize())
        );
    },

    /**
     * Adds new custom meta
     */
    addCustomMeta: function() {
        var div = $('<div>', {'class': 'fields'}),
            label = $('<label>').html(custom_meta),
            inputName  = $('<input>', {type:'text', title:'Meta Name', 'class':'meta-name'}),
            inputValue = $('<input>', {type:'text', title:'Meta Content', 'class':'meta-value'});

        div.append(label);
        div.append(inputName);
        div.append(inputValue);
        $('#customMeta').append(div);
    },

    /**
     * Update meta
     */
    submitMetaForm: function() {
        var customMeta   = [],
            customInputs = $('#customMeta input.meta-name');

        customInputs.each(function(index, input) {
            if (!$(input).val()) {
                $(input).parent().empty();
                return;
            }
            customMeta[index] = [$(input).val(), $(input).next().val()];
        });

        var settings = $.unserialize($('#settingsForm input,select,textarea').serialize());
        settings["site_custom_meta"] = customMeta;
        this.gadget.ajax.call('UpdateMetaSettings', settings);
    },

    /**
     * Update mail-server settings
     */
    submitMailSettingsForm: function() {
        this.gadget.ajax.call(
            'UpdateMailSettings',
            $.unserialize($('#settingsForm input,select,textarea').serialize())
        );
    },

    /**
     * Update proxy settings
     */
    submitProxySettingsForm: function() {
        this.gadget.ajax.call(
            'UpdateProxySettings',
            $.unserialize($('#settingsForm input,select,textarea').serialize())
        );
    },

    toggleGR: function() {
        if ($('#use_gravatar').val() == 'yes') {
            $('#gravatar_rating').prop('disabled', false);
        } else {
            $('#gravatar_rating').prop('disabled', true);
        }
    },

    changeMailer: function() {
        $('#settingsForm input,select,textarea').not('#mailer').prop("disabled", true);
        switch($('#mailer').val()) {
            case 'phpmail':
                $('#settingsForm #gate_email,#gate_title').prop("disabled", false);
                break;
            case 'sendmail':
                $('#settingsForm #gate_email,#gate_title,#sendmail_path').prop("disabled", false);
                break;
            case 'smtp':
                $('#settingsForm input,select,textarea').not('#mailer').prop("disabled", false);
                $('#settingsForm #sendmail_path').prop("disabled", true);
                break;
        }
    },

    /**
     * Update ftp-server settings
     */
    submitFTPSettingsForm: function() {
        this.gadget.ajax.call(
            'UpdateFTPSettings',
            $.unserialize($('#settingsForm input,select,textarea').serialize())
        );
    },

    /**
     * initialize gadget actions
     */
    init: function(mainGadget, mainAction) {
        // init mail settings action
        if (this.gadget.actions.hasOwnProperty('MailSettings')) {
            this.changeMailer();
        }
    },

}};

function Jaws_Gadget_Settings_Action_BasicSettings() { return {
    // ASync callback method
    AjaxCallback : {
    },

    /**
     * Update basic settings
     */
    submitBasicForm: function() {
        this.ajax.call(
            'UpdateBasicSettings',
            $.unserialize($('#settingsForm input,select,textarea').serialize())
        );
    },

}};